@@ -79,7 +79,7 @@ KlamDB::KlamDB( QWidget* parent, const char* name, bool modal, WFlags fl )
 	button = new KToolBarButton( "locationbar_erase", 0, searchToolBar );
 
 	VirusList = new KListView( privateLayoutWidget, "VirusList" );
-	VirusList->addColumn( "All Known Viruses",150 );
+	VirusList->addColumn( i18n( "All Known Viruses" ),150 );
 /*	VirusList->setResizeMode(QListView::AllColumns);
 	VirusList->setColumnWidthMode(0,QListView::Maximum);*/
 	connect(VirusList, SIGNAL( doubleClicked( QListViewItem * , const QPoint &, int ) ),
@@ -109,9 +109,10 @@ KlamDB::KlamDB( QWidget* parent, const char* name, bool modal, WFlags fl )
         else
           ticon = QPixmap( iconPath );
 
-        menu->insertItem(vicon, "Search in VirusPool", this,SLOT(slotVirusPool()) );
-        menu->insertItem(ticon, "Search with Trend Micro", this,SLOT(slotTrendMicro()) );
-        menu->insertItem(gicon, "Search with Google", this,SLOT(slotGoogle()) );
+        menu->insertItem(vicon, i18n("Search in VirusList"), this,SLOT(slotVirusList()) );
+        menu->insertItem(vicon, i18n("Search in VirusPool"), this,SLOT(slotVirusPool()) );
+        menu->insertItem(ticon, i18n("Search with Trend Micro"), this,SLOT(slotTrendMicro()) );
+        menu->insertItem(gicon, i18n("Search with Google"), this,SLOT(slotGoogle()) );
 
     	connect(VirusList, SIGNAL( contextMenuRequested( QListViewItem *, const QPoint& , int ) ), 
 		this, SLOT( slotRMB( QListViewItem *, const QPoint &, int ) ) );
@@ -120,7 +121,7 @@ KlamDB::KlamDB( QWidget* parent, const char* name, bool modal, WFlags fl )
 	QValueList<int> columns;
         columns.append(0);
 	kLineEdit1->setSearchColumns(columns);
-	kLineEdit1->setMaxLength(3);
+	kLineEdit1->setMaxLength(2);
 	connect(button, SIGNAL( clicked() ),
 	                kLineEdit1, SLOT(clear()) );
 
@@ -151,12 +152,12 @@ KlamDB::~KlamDB()
  */
 void KlamDB::languageChange()
 {
-	setCaption( tr( "Form1" ) );
-	tabBrowser->changeTab( tab, tr( "Info" ) );
-	VirusList->header()->setLabel( 0, tr( "All Known Viruses" ) );
+	setCaption( i18n( "Form1" ) );
+	tabBrowser->changeTab( tab, i18n( "Info" ) );
+	VirusList->header()->setLabel( 0, i18n( "All Known Viruses" ) );
 	VirusList->clear();
-	KListViewItem * item = new KListViewItem( VirusList, 0 );
-	item->setText( 0, tr( "New Item" ) );
+	/*KListViewItem * item =*/ new KListViewItem( VirusList, 0 );
+	//item->setText( 0, tr( "New Item" ) );
 
 }
 
@@ -388,6 +389,41 @@ int KlamDB::listdir(const char *dirname)
 	return 0;
 }
 
+int KlamDB::checkdir(const char *dirname)
+{
+	DIR *dd;
+	struct dirent *dent;
+
+
+	if((dd = opendir(dirname)) == NULL) {
+	    printf("!Can't open directory %s\n", dirname);
+	    return -1;
+	}
+
+	int found = 0;
+	while((dent = readdir(dd))) {
+#ifndef C_INTERIX
+	if(dent->d_ino)
+#endif
+	{
+	    if(strcmp(dent->d_name, ".") && strcmp(dent->d_name, "..") &&
+	    (cli_strbcasestr(dent->d_name, ".db")  ||
+	     cli_strbcasestr(dent->d_name, ".db2") ||
+	     cli_strbcasestr(dent->d_name, ".hdb") ||
+	     cli_strbcasestr(dent->d_name, ".ndb") ||
+	     cli_strbcasestr(dent->d_name, ".cvd"))) {
+		found = 1;
+	    }
+	}
+	}
+
+	closedir(dd);
+	
+	if (!(found))
+		return -1;
+	return 0;
+}
+
 int cli_untgz(int fd, const char *destdir)
 {
 	char *fullname, osize[13], name[101], type;
@@ -658,19 +694,32 @@ char *cli_strtok(const char *line, int fieldno, const char *delim)
 
 void KlamDB::shouldIShow(QWidget * current)
 {
-	static struct cl_stat *dbstat=NULL;
-	
 
+	static struct cl_stat *dbstat=NULL;
+	QString location;
 
 	if ((current == this) && (!(loadinprogress))){
+		QString db = kmain->freshklam->getCurrentDBDir();
+	
+		if (checkdir((const char *)db) == -1){
+			kdDebug() << "returned -1" << endl;
+			location = locate("data", "klamav/about/nodb.html");
+			homepage->openURL(location);
+	
+			return;
+		}
+
+
+		if ( ((cl_statchkdir(dbstat) == 1) || (dbstat == NULL))) {
+			location = locate("data", "klamav/about/wait.html");
+			homepage->openURL(location);
 
-		if ( (cl_statchkdir(dbstat) == 1) || (dbstat == NULL)){
                         loadinprogress = true;
 			sigs = ( int )getSigNos();
-			progress = new KProgressDialog (this, "progress", "Loading ..", "Loading...", true);
+			progress = new KProgressDialog (this, "progress", i18n( "Loading .." ), i18n( "Loading..." ), true);
 			progress->setAllowCancel(false);
 			prog = progress->progressBar();
-			progress->setLabel("Loading lots and lots and lots of virus information");
+			progress->setLabel(i18n( "Loading lots and lots and lots of virus information" ));
 			
 			
 			prog->setTotalSteps(sigs);
@@ -678,12 +727,13 @@ void KlamDB::shouldIShow(QWidget * current)
 			//kdDebug() << prog->totalSteps() << endl;
 			
 			VirusList->hide();
-			VirusList->clear();
+            if (VirusList->childCount() > 0)
+                VirusList->clear();
 			count = 0;
 			prog->setProgress (count);
 			kapp->processEvents();
 
-			QString db = kmain->freshklam->getCurrentDBDir();
+// 			QString db = kmain->freshklam->getCurrentDBDir();
 
 			listdir((const char *)db);
 
@@ -702,9 +752,14 @@ void KlamDB::shouldIShow(QWidget * current)
 
 			cl_statinidir((const char *)db, dbstat);
 			
-                        loadinprogress = false;
-			QString location = locate("data", "klamav/about/main.html");
-			homepage->openURL(location);
+          
+			loadinprogress = false;
+			// Default english
+			QString location = locate( "data", "klamav/about/main-" + KGlobal::locale()->language() + ".html" );
+			if( location != QString::null )
+				homepage->openURL( location );
+			else
+				homepage->openURL( locate("data", "klamav/about/main.html") );
 
 		}
 	}
@@ -718,7 +773,7 @@ void KlamDB::addVirusName(char *start)
 	kapp->processEvents();
 	if ((count % 500) == 0){
 		//progress->setLabel("Loading " + QString(start));
-		progress->setLabel("Loading ClamAV's Database of Virus Signatures");
+		progress->setLabel( i18n( "Loading ClamAV's Database of Virus Signatures") );
 		prog->setProgress (count);
 		kapp->processEvents();
 	}
@@ -733,7 +788,7 @@ unsigned int  KlamDB::getSigNos()
         
 	unsigned int ret= 0;
 	unsigned int no = 0;
-        struct cl_node *root = NULL;
+    struct cl_node *root = NULL;
 	QStringList lastDownloadPaths;
 	QString dbdir;
 	QString db;
@@ -746,6 +801,7 @@ unsigned int  KlamDB::getSigNos()
 
 	ret = cl_loaddbdir((const char *)dbdir, &root, &no);
 	//kdDebug() << "no " << no << endl;
+    cl_free(root);
 	return no;
 
 }
@@ -764,7 +820,7 @@ void KlamDB::slotOpenTab(QListViewItem * item, const QPoint& , int )
 
     QString url = item->text(0);
     
-    Frame *frame=new Frame(this, page, page->widget(), "VirusPool : "+item->text(0));
+    Frame *frame=new Frame(this, page, page->widget(), "VirusList : "+item->text(0));
     //connectFrame(frame);
     tabBrowser->addFrame(frame);
 
@@ -775,7 +831,7 @@ void KlamDB::slotOpenTab(QListViewItem * item, const QPoint& , int )
     
     //if (m_tabs->count() > 1 && m_tabs->currentPageIndex() != 0)
 //        m_tabsClose->setEnabled(true);
-    page->openURL("http://viruspool.vanderkooij.org/virus.cms?&name="+url);
+    page->openURL("http://www.viruslist.com/en/find?search_mode=virus&words="+url);
 }
 
 void KlamDB::slotOpenTabPlain(const KURL& url, bool background)
@@ -828,10 +884,12 @@ void KlamDB::slotOpenHome()
         tabBrowser->showPage(homepage->widget());
 //    else
         setFocus();
-
-    QString location = locate("data", "klamav/about/wait.html");
-
-    homepage->openURL(location);
+        
+    QString location = locate( "data", "klamav/about/wait-" + KGlobal::locale()->language() + ".html" );
+    if( location != QString::null )
+       homepage->openURL( location );
+    else
+       homepage->openURL( locate("data", "klamav/about/wait.html") );
 }
 
 void KlamDB::slotRMB( QListViewItem* Item, const QPoint & point, int )
@@ -862,6 +920,13 @@ void KlamDB::slotVirusPool()
 	slotOpenPrefix(prefix,"VirusPool",url);
 }
 
+void KlamDB::slotVirusList()
+{
+	QString url = VirusList->selectedItem()->text(0);
+	QString prefix = QString("http://www.viruslist.com/en/find?search_mode=virus&words=");
+	slotOpenPrefix(prefix,"VirusList",url);
+}
+
 void KlamDB::slotGoogle()
 {
 
@@ -887,9 +952,11 @@ void KlamDB::slotExternal(QString name,QString service)
 		prefix = QString("http://viruspool.vanderkooij.org/virus.cms?&name=");
 	else if (service == "Google")
 		prefix = QString("http://www.google.com/search?ie=ISO-8859-1&q=");
+        else if (service == "VirusList")
+                prefix = QString("http://www.viruslist.com/en/find?search_mode=virus&words=");
 	else
 		prefix = QString("http://www.trendmicro.com/vinfo/virusencyclo/default2.asp?m=q&virus=");
 	slotOpenPrefix(prefix,service,name);
 }
 
-#include "dbviewer.moc"
\ No newline at end of file
+#include "dbviewer.moc"
