@@ -6,7 +6,9 @@
 #include "freshklam.h"
 #include "klamav.h"
 #include "klamd.h"
-
+#include "collectiondb.h"
+/*#include "gmanedb.h"*/
+#include "klamavconfig.h"
 
 #include <klocale.h>
 #include <kio/netaccess.h>
@@ -31,6 +33,7 @@
 #include <dom/html_misc.h>
 #include <kapplication.h>
 #include <dcopclient.h>
+#include <kuser.h>
 
 #include <qtimer.h>
 
@@ -68,35 +71,23 @@ const char *check_desc[] = {
     0
 };
 
-const char *mirrors[] = {
-    "heanet",
-    "internap",
-    "surfnet",
-    "umn",
-    "nchc",
-    "ufpr",
-    "unc",
-    "jaist",
-    "voxel",
-    "citkit",
-    "optusnet",
-    "ovh",
-    "mesh",
-    "easynews",
-    "switch",
-    "kent",
-    "puzzle",
-    0
-};
 
+QString readymessage = i18n("KlamAV ") + KLAMAV_VERSION + i18n(" - Ready");
 
 Freshklam::Freshklam(QWidget *parent, const char *name)
     : QWidget(parent, name)
 {
 
+//    MetaDB* updater = new MetaDB();
+//    updater->update();
+    updater = new KlamavUpdate(this);
+    connect( updater,   SIGNAL( getCurrentVersionOfClamAV() ), SLOT( getCurrentVersionOfClamAV() ) );
+    connect( updater,   SIGNAL( toggleUpgradeButtons(bool) ), SLOT( toggleUpgradeButtons(bool) ) );
+
+
 
     kmain->firstDownload = false;
-    upgradeinprogress = false;
+    checkingDirectly = false;
     
 
     freshklamAlive = FALSE;
@@ -148,17 +139,17 @@ Freshklam::Freshklam(QWidget *parent, const char *name)
 
 
 
-    clamav_options = new QPushButton ("Upgrade ClamAV Now", dazuko_hlp);
+    clamav_options = new QPushButton (i18n( "Upgrade ClamAV Now" ), dazuko_hlp);
     dazuko_dir_layout->addWidget(clamav_options,1,0);
     clamav_options->setFixedSize(clamav_options->sizeHint());
     connect( clamav_options, SIGNAL( clicked() ), this,
-		SLOT( checkForNewClamAVDirectly() ) );
+		SLOT( checkForNewClamAVNow() ) );
 
-    klamav_options = new QPushButton ("Upgrade KlamAV Now", dazuko_hlp);
+    klamav_options = new QPushButton (i18n( "Upgrade KlamAV Now" ), dazuko_hlp);
     dazuko_dir_layout->addWidget(klamav_options,1,1);
     klamav_options->setFixedSize(klamav_options->sizeHint());
     connect( klamav_options, SIGNAL( clicked() ), this,
-		SLOT( checkForNewKlamAVDirectly() ) );
+		SLOT( checkForNewKlamAVNow() ) );
 
 
 
@@ -293,7 +284,7 @@ Freshklam::Freshklam(QWidget *parent, const char *name)
     status_frame->setFrameStyle(QFrame::Panel | QFrame::Sunken);
     QBoxLayout *status_layout = new QHBoxLayout(status_frame, 2);
 
-    status_label = new QLabel(i18n("Ready"), status_frame);
+    status_label = new QLabel(readymessage, status_frame);
     status_layout->addWidget(status_label, 10);
 
     status_layout->activate();
@@ -350,34 +341,39 @@ void Freshklam::processOutput()
         errorMessage = item2.mid(pos,pos2);
     }
 
-    if (((pos = item2.find("Recommended version:")) != -1) && 
-        !(upgradeinprogress) && 
-        (clamav_box->isChecked())){
-        pos2 = item2.find('\n',pos);
-
-        QString version = item2.mid((pos+20),pos2 - (pos+20)).stripWhiteSpace();
-
-        int result = KMessageBox::warningContinueCancel(this, i18n( "It looks like your version of the ClamAV engine is out of date! ClamAV-%1 is the most recent version of ClamAV available. Would you like to KlamAV to download and compile it for you?").arg(version),i18n( "Download and Install ClamAV-%1" ).arg(version),i18n( "Download and Install ClamAV-%1" ).arg(version));
-    
-        switch (result) {
-            case 2 : 
-                break;
-            case 5 : 
-                downloadComponent("clamav",version,"tar.gz");
-        }
-
-    }
-
     if ((pos = item2.find("Database updated")) != -1){
+	   CollectionDB::instance()->insertEvent("Updates","Database Updated",dir_combo->url());
         KNotifyClient::event(kmain->_tray->winId(),"UpdatedDatabase", "Virus Database Updated.");
         updateMailClient();
     }
 
     if ((pos = item2.find("daily.cvd is up to date")) != -1){
+	   CollectionDB::instance()->insertEvent("Updates","Database Already Up To Date",dir_combo->url());
         KNotifyClient::event(kmain->_tray->winId(),"UpdatedDatabase", "Virus Database Up To Date.");
         updateMailClient();
     }
 
+
+    if ((pos = item2.find("Recommended version:")) != -1){
+
+        pos2 = item2.find('\n',pos);
+        QString version = item2.mid((pos+20),pos2 - (pos+20)).stripWhiteSpace();
+
+        if ((clamav_box->isChecked())){
+    
+            int result = KMessageBox::warningContinueCancel(this, i18n( "It looks like your version of the ClamAV engine is out of date! ClamAV-%1 is the most recent version of ClamAV available. Would you like to KlamAV to download and compile it for you?").arg(version),i18n( "Download and Install ClamAV-%1" ).arg(version),i18n( "Download and Install ClamAV-%1" ).arg(version));
+        
+            switch (result) {
+                case 2 : 
+                    break;
+                case 5 : 
+                    updater->downloadComponent("clamav",version,"tar.gz");
+            }
+        }else if (!(clamav_box->isChecked()))
+            KNotifyClient::event(kmain->_tray->winId(),"ClamAVOutDated", QString("Your copy of ClamAV is out of date! Please Upgrade to ClamAV %1!").arg(version));
+    }
+
+
 }
 
 
@@ -386,14 +382,20 @@ void Freshklam::slotSearch()
 
     search_button->setEnabled(false);
     cancel_button->setEnabled(true);
-    
-    status_label->setText(i18n("Beginning Update..."));
-    
+
     QString filepattern = dir_combo->url();
     
-    childproc = new KShellProcess();
-    QString command = "freshclam --stdout";
+    CollectionDB::instance()->insertEvent("Updates","Commencing DB Update", filepattern);
+
+    status_label->setText(i18n("Beginning Update..."));
     
+    
+    childproc = new KShellProcess();
+    QString command = "freshclam --stdout ";
+    
+    QString user = KUser().loginName();
+    command += " --user=" + user + " ";
+
     if (!(filepattern.isEmpty())){
         command += " --datadir=";
         command += filepattern;
@@ -406,7 +408,7 @@ void Freshklam::slotSearch()
         if ( tf.status() != 0 ) {
             tf.close();
             //delete tf;
-            KMessageBox::information (this,"There was an error creating a temp file!");
+            KMessageBox::information (this,i18n( "There was an error creating a temp file!") );
             return;
         }
         pidFileName = tf.name();
@@ -419,7 +421,7 @@ void Freshklam::slotSearch()
 
         if (kmain->klamd->isKlamdAlive()){
             QString klamdconf = kmain->klamd->getKlamdConfFile();
-            //kdDebug() << klamdconf << endl;
+            ////kdDebug() << klamdconf << endl;
             command += " --daemon-notify=";
             command += klamdconf;
         }        
@@ -431,14 +433,17 @@ void Freshklam::slotSearch()
     
     disableInputs();
     
-    
+
     *childproc << command;
     
+    //kdDebug() << command << endl;
+
+    childproc->start(KProcess::NotifyOnExit, KProcess::Stdout);
+
     connect( childproc, SIGNAL(processExited(KProcess *)),
         SLOT(childExited()) );
     connect( childproc, SIGNAL(receivedStdout(KProcess *, char *, int)),
         SLOT(receivedOutput(KProcess *, char *, int)) );
-    childproc->start(KProcess::NotifyOnExit, KProcess::Stdout);
     
     if (kmain->klamd->isKlamdAlive())
         kmain->_tray->setPixmap(KSystemTray::loadIcon("klamavdl"));    
@@ -472,8 +477,23 @@ void Freshklam::finish()
     kmain->EnableFreshklam->setEnabled(TRUE);
     kmain->DisableFreshklam->setEnabled(FALSE);
 
+    updateMetaDB();
+
 }
 
+void Freshklam::updateMetaDB()
+{
+
+    QDate latestDate = QDate::fromString(CollectionDB::instance()->latestMetaDBDate(),Qt::ISODate);
+    QDate today = QDate::currentDate();
+    kdDebug() << latestDate << " " << today << endl;
+
+    if (latestDate.daysTo(today) > 31){
+/*           MetaDB* updater = new MetaDB();
+           updater->update();*/
+    }
+
+}
 
 void Freshklam::slotCancel()
 {
@@ -481,21 +501,22 @@ void Freshklam::slotCancel()
     
     if (daemon_box->isChecked()){
         if (!(killPID()))
-            KMessageBox::information (this,"There was a problem killing the update process!");
+            KMessageBox::information (this,i18n( "There was a problem killing the update process!") );
     }
 
     status_label->setText(i18n("Canceled"));
-
+    CollectionDB::instance()->insertEvent("Updates","Database Update Cancelled", dir_combo->url());
 
 }
 
 void Freshklam::processDied()
 {
     
-    KMessageBox::information (this,"Update Process died unexpectedly! Did you kill it manually?");
+    KMessageBox::information (this,i18n( "Update Process died unexpectedly! Did you kill it manually?" ));
 
     status_label->setText(i18n("Update Process Died Unexpectedly!"));
 
+    CollectionDB::instance()->insertEvent("Updates","Database Update Process Died Unexpectedly",dir_combo->url());
 
 }
 
@@ -523,38 +544,38 @@ void Freshklam::childExited()
         //KMessageBox::information (this,"No Update Required - Database already up to date!");
         //updateMailClient();
     }else if (status == 40)
-    KMessageBox::information (this,"Unknown option passed.");
+    KMessageBox::information (this, i18n("Unknown option passed."));
     else if (status == 50)
-    KMessageBox::information (this,"Can't change directory.");
+    KMessageBox::information (this, i18n("Can't change directory."));
     else if (status == 51)
-    KMessageBox::information (this,"Can't check MD5 sum.");
+    KMessageBox::information (this, i18n("Can't check MD5 sum."));
     else if (status == 52)
-    KMessageBox::information (this,"Connection (network) problem.");
+    KMessageBox::information (this, i18n("Connection (network) problem."));
     else if (status == 53)
-    KMessageBox::information (this,"Can't unlink a file.");
+    KMessageBox::information (this, i18n("Can't unlink a file."));
     else if (status == 54)
-    KMessageBox::information (this,"MD5 or digital signature verification error.");
+    KMessageBox::information (this, i18n("MD5 or digital signature verification error."));
     else if (status == 55)
-    KMessageBox::information (this,"Error reading file.");
+    KMessageBox::information (this, i18n("Error reading file."));
     else if (status == 56)
-    KMessageBox::information (this,"Config file error.");
+    KMessageBox::information (this, i18n("Config file error."));
     else if (status == 57)
-    KMessageBox::information (this,"Can't create a new file.");
+    KMessageBox::information (this, i18n("Can't create a new file."));
     else if (status == 58)
-    KMessageBox::information (this,"Can't read database from remote server.");
+    KMessageBox::information (this, i18n("Can't read database from remote server."));
     else if (status == 59)
-    KMessageBox::information (this,"Mirrors are not fully synchronized (try again later).");
+    KMessageBox::information (this, i18n("Mirrors are not fully synchronized (try again later)."));
     else if (status == 60)
-    KMessageBox::information (this,"Can't get information about clamav user from /etc/passwd.");
+    KMessageBox::information (this, i18n("Can't get information about clamav user from /etc/passwd."));
     else if (status == 61)
-    KMessageBox::information (this,"Can't drop privileges.");
+    KMessageBox::information (this, i18n("Can't drop privileges."));
     else
-    KMessageBox::information (this,"Warning - Unknown Error!");
+    KMessageBox::information (this, i18n("Warning - Unknown Error!"));
 
     if (errorMessage != "")
         KMessageBox::information (this,errorMessage);
     errorMessage = "";
-    status_label->setText( i18n("Ready") );
+    status_label->setText( readymessage );
 
     //if (status != 0)
           //matches_label->setText("");
@@ -565,6 +586,7 @@ void Freshklam::updateMailClient()
 
 {
 
+
     config->setGroup("Freshklam");
     
     if (lastDownloadPaths.contains(dir_combo->/*currentText*/url()) == 0) {
@@ -590,9 +612,9 @@ void Freshklam::updateMailClient()
     config->sync();
 
     
-    config = new KConfig("kmailrc");
-    config->setGroup("General");
-    QVariant nooffilters = config->readEntry("filters");
+    KConfig* mailconfig = new KConfig("kmailrc");
+    mailconfig->setGroup("General");
+    QVariant nooffilters = mailconfig->readEntry("filters");
 
     int result;    
     int numfilters = nooffilters.toInt();
@@ -600,8 +622,8 @@ void Freshklam::updateMailClient()
     for (int j=0; j != numfilters; j++ ){
         QVariant numb = j;
         QString filtername=QString("Filter #%1").arg(numb.toString());
-        config->setGroup(filtername);
-        QString binary = config->readEntry("action-args-0");
+        mailconfig->setGroup(filtername);
+        QString binary = mailconfig->readEntry("action-args-0");
         if (binary.find("klammail") != -1){
             QString pathonly = binary.section(" ",2,2);
             if (pathonly == dir_combo->url())
@@ -614,8 +636,8 @@ void Freshklam::updateMailClient()
                 switch (result) {
                     case 2 : KMessageBox::information (this,"KMail has not been updated with the new database location.");  break;
                     case 5 :
-                    config->writeEntry("action-args-0",QString("klammail -d %1").arg(dir_combo->url()));
-                    config->sync();
+                    mailconfig->writeEntry("action-args-0",QString("klammail -d %1").arg(dir_combo->url()));
+                    mailconfig->sync();
                     break;
 
                 }
@@ -625,9 +647,12 @@ void Freshklam::updateMailClient()
     }
     //KMessageBox::information (this,"Database Update Complete!");
 
+    delete mailconfig;
+
 }
 void Freshklam::receivedOutput(KProcess */*proc*/, char *buffer, int buflen)
 {
+    //kdDebug() << buffer << endl;
     buf += QCString(buffer, buflen+1);
     processOutput();
 }
@@ -654,7 +679,7 @@ void Freshklam::writeConf()
     if ( tf.status() != 0 ) {
         tf.close();
         //delete tf;
-        KMessageBox::information (this,"KMFilterActionWithCommand: Could not create temp file!");
+        KMessageBox::information (this,i18n( "KMFilterActionWithCommand: Could not create temp file!" ));
         return;
     }
     
@@ -673,17 +698,15 @@ void Freshklam::writeConf()
         if ( proxyPort->hasAcceptableInput() ) {
             ts << QString("HTTPProxyPort %1").arg(proxyPort->text()) << "\n";
         }
-        if ( proxyUser->hasAcceptableInput() ) {
+        if ( proxyUser->hasAcceptableInput() && ! proxyUser->text().isEmpty() ) {
             ts << QString("HTTPProxyUsername %1").arg(proxyUser->text()) << "\n";
+            if ( proxyPass->hasAcceptableInput() ) {
+               ts << QString("HTTPProxyPassword %1").arg(proxyPass->text()) << "\n";
+            }
         }
-        if ( proxyPass->hasAcceptableInput() ) {
-            ts << QString("HTTPProxyPassword %1").arg(proxyPass->text()) << "\n";
-        }
-    }else{
-        return;
-    }
-
-    //tf.close();
+    } 
+    else
+       return;
 }
 
 
@@ -759,7 +782,7 @@ bool  Freshklam::killPID(){
         line = is.readLine();
     inf.close();
 
-    //kdDebug() << line << endl;
+    ////kdDebug() << line << endl;
     if (!(line.isEmpty()))
         kill(line.toInt(), SIGKILL);
     else
@@ -813,7 +836,7 @@ QString  Freshklam::getCurrentDBDir(){
 
     if (dbdir != dir_combo->url()){
         ret = cl_loaddbdir((const char *)dir_combo->url(), &root, &no);
-        //kdDebug() << "ret " << ret << endl;
+        ////kdDebug() << "ret " << ret << endl;
         if (no == 0){
             db = dbdir;
         }else{
@@ -861,12 +884,12 @@ void  Freshklam::createDBDir(){
         
     }
     
-    KMessageBox::information (this,QString(ok ? "Your Virus Database location has been set up as '%1'. You can change this to something else if you want to." : "I cannot create the directory '%1' for you. Something is wrong with your HOME or klamav directory. You have to adjust your Virus Database directory by your self.").arg(path));
+    KMessageBox::information (this,QString(ok ? i18n( "Your Virus Database location has been set up as '%1'. You can change this to something else if you want to." ) : i18n( "I cannot create the directory '%1' for you. Something is wrong with your HOME or klamav directory. You have to adjust your Virus Database directory by your self." )).arg(path));
 
     if (ok){
         int result = KMessageBox::warningContinueCancel(this, i18n( "Would you like to download the latest Virus Database to your new database location now? (You can do this later manually if you want.)"),i18n( "Download Virus Database" ),i18n( "Download" ));
             switch (result) {
-                case 2 : KMessageBox::information (this,"You should update the database manually at your earliest convenience.");  break;
+                case 2 : KMessageBox::information (this,i18n( "You should update the database manually at your earliest convenience.") );  break;
                 case 5 : 
                     kmain->firstDownload = true;
                     break;
@@ -883,263 +906,29 @@ bool  Freshklam::isFreshklamAlive(){
 
 }
 
-void Freshklam::downloadComponent(QString component, QString version, QString extension)
+
+void Freshklam::enableAutoUpdates()
 {
 
-    upgradeinprogress = true;
-
-    QString location = getenv("HOME");
-
-    location += "/.klamav";
-    QDir klamavdir(location);
-    if (!klamavdir.exists() && !klamavdir.mkdir(location))
-        location = getenv("HOME");
-
-    QString currentclamav = location + QString("/%1-%2").arg(component).arg(version);
-    QDir clamavdir(currentclamav);
-
-    QString configure;
-    if (component == "klamav"){
-        configure = QString("%1/%2-%3/%4-%5/configure").arg(location).arg(component).arg(version).arg(component).arg(version);
-
-    }else{
-        configure = QString("%1/%2-%3/configure").arg(location).arg(component).arg(version);
-    }
-    QFile configurefile(configure);
-
-    bool download = true;
-
-    if (clamavdir.exists() && configurefile.exists()){
-        int result = KMessageBox::questionYesNo(this, i18n( "You seem to have downloaded %1-%2 already (in %3/%4-%5). Would you like to skip re-downloading it and just try to compile it?").arg(component).arg(version).arg(location).arg(component).arg(version),i18n( "Compile %1" ).arg(component));
-
-        switch (result) {
-            case 2 : 
-                download = true;break;
-            case 3 : 
-                download = false;
-        }
-    }
-
-    if (download){
-
-        startProgressDialog( i18n( "Downloading %1-%2..." ).arg(component).arg(version) );
- 
-        QString tmpFile;
-        if ( !KIO::NetAccess::download( QString("http://%1.dl.sourceforge.net/sourceforge/%2/%3-%4.%5").arg(getMirror()).arg(component).arg(component).arg(version).arg(extension), tmpFile, 0L ) ){
-            KMessageBox::information (this,i18n("Couldn't download %1.").arg(component));
-            delete timer;
-            timer=0;
-            delete progressDialog;
-            progressDialog = 0;
-            upgradeinprogress = false;
-            return;
-        }
-    
-        //kdDebug() << "Theme is in temp file: " << tmpFile << endl;
-    
-        if ((progressDialog) && (progressDialog->wasCancelled())){
-            updateCanceled();
-            return;
-        }
-    
-        
-    
-        progressDialog->setLabel(QString("Unpacking %1-%2 to %3/%4-%5").arg(component).arg(version).arg(location).arg(component).arg(version));
-    
-        // unpack the tarball
-        KTar tar( tmpFile );
-        tar.open( IO_ReadOnly );
-        tar.directory()->copyTo( location );
-        tar.close();
-
-    
-        // remove the temp file
-        KIO::NetAccess::removeTempFile( tmpFile );
-    
-        delete timer;
-        timer=0;
-        delete progressDialog;
-        progressDialog = 0;
-    }
-
-    if ((progressDialog) && (progressDialog->wasCancelled())){
-        updateCanceled();
-        delete progressDialog;
-        progressDialog = 0;
-        return;
-    }
-
-    //KTar does not honour executable permissions
-
-    if (clamavdir.exists() && configurefile.exists()){
-
-        chmod((const char *)configure,0700);
-        if (component == "klamav"){
-            QString dazukoconfigure = QString("%1/%2-%3/dazuko/configure").arg(location).arg(component).arg(version);
-
-            chmod((const char *)dazukoconfigure,0700);
-        }
-
-        int result = KMessageBox::warningContinueCancel(this, i18n( "%1-%2 is ready for compiling and installation. Would you like the wizard to ask you for the root password so it can compile and install it for you? (If not, you can compile it yourself later at %3/%4-%5)").arg(component).arg(version).arg(location).arg(component).arg(version),i18n( "Install %1-%2" ).arg(component).arg(version),i18n( "Use the Wizard" ));
-        
-        switch (result) {
-            case 2 : 
-                KMessageBox::information (this,i18n("Installation of %1 Cancelled.").arg(component));
-                upgradeinprogress = false;
-                break;
-            case 5 : 
-
-                KProcess* arkollonproc = new KShellProcess();
-                //make sure we catch arkollon in the .klamav directory
-// 	        QString curpath = (QString) getenv("PATH");
-//                 QString homedir = (QString) getenv("HOME");
-// 	        arkollonproc->setEnvironment("PATH",homedir+"/.klamav/bin:" + curpath);
-
-                QString command = QString("klamarkollon %1/%2-%3").arg(location).arg(component).arg(version);
-                *arkollonproc << command;
-                if (component == "klamav")
-                connect( arkollonproc, SIGNAL(processExited(KProcess *)), SLOT(klamavInstallationExited(KProcess *)) );
-                else
-                    connect( arkollonproc, SIGNAL(processExited(KProcess *)), SLOT(clamavInstallationExited(KProcess *)) );
-                arkollonproc->start();
-        }
-    }
-    
-}
-
-void Freshklam::checkForNewKlamAV()
-{
-
-    kdDebug() << "Checking for new KlamAV" << endl;
-
-    highestsofarnumeric = 0;
-    klamav_url = "http://prdownloads.sourceforge.net/klamav/";
-    getLatestVersionFromSFHack(klamav_url);
+        config = KGlobal::config();
+        config->writeEntry("AutoUpdate","Yes");
+        config->sync();
+        daemon_box->setChecked(true);
+        check_combo->setEnabled(true);
+	slotSearch();
 
 }
 
-void Freshklam::checkForNewKlamAVDirectly()
+void Freshklam::checkForNewClamAVNow()
 {
 
-    kdDebug() << "Checking for new KlamAV" << endl;
-
-    checkingDirectly = true;
-
-    highestsofarnumeric = 0;
-    klamav_url = "http://prdownloads.sourceforge.net/klamav/";
-    startProgressDialog( i18n( "Checking for new version of KlamAV..." ) );
-
-    getLatestVersionFromSF(klamav_url);
-
+    updater->checkForNewClamAVDirectly();
 }
 
-
-void Freshklam::checkForNewClamAVDirectly()
+void Freshklam::checkForNewKlamAVNow()
 {
 
-    kdDebug() << "Checking for new ClamAV" << endl;
-
-    checkingDirectly = true;
-
-    highestsofarnumeric = 0;
-    clamav_url = "http://prdownloads.sourceforge.net/clamav/";
-
-    startProgressDialog( i18n( "Checking for new version of ClamAV..." ) );
-    
-    getLatestVersionFromSF(clamav_url);
-
-}
-
-void Freshklam::completedSearchForUpdates(const QString &component, const QString &extension)
-{
-
-    double currentversion;
-
-    if (component == "KlamAV")
-        currentversion = VERSION_KLAMAV;
-    else{
-        if (currentClamAVVersion.mid(currentClamAVVersion.length() - 2,1) == ".")
-            currentversion = currentClamAVVersion.replace(currentClamAVVersion.length() - 2,1,"").toDouble();
-        else
-            currentversion = currentClamAVVersion.toDouble();
-    }
-
-    //kdDebug() << "in completed search for updates" << endl;
-    //kdDebug() << currentversion << endl;
-    //kdDebug() << highestsofarnumeric << endl;
-
-    if (highestsofarnumeric > currentversion){
-        int result = KMessageBox::warningContinueCancel(this, i18n( "It looks like your version of %1 is out of date! %2-%3 is the most recent version available. Would you like KlamAV to download and compile it for you?").arg(component).arg(component).arg(highestsofarraw),i18n( "Download and Install %1-%2" ).arg(component).arg(highestsofarraw),i18n( "Download and Install %1-%2" ).arg(component).arg(highestsofarraw));
-    
-        switch (result) {
-            case 2 : 
-                break;
-            case 5 : 
-                downloadComponent(component.lower(), highestsofarraw, extension);
-        }
-    }else if (checkingDirectly){
-        KMessageBox::information (this,i18n("Your installation of %1 is already up-to-date!").arg(component));
-    }
-    checkingDirectly = false;
-    klamav_options->setEnabled(true);
-    clamav_options->setEnabled(true);
-
-    if (filelist)
-        filelist->deleteLater();
-
-}
-
-
-
-void Freshklam::startProgressDialog( const QString & text )
-{
-    //if ( progressDialog )
-    //    delete progressDialog;
-
-    progressDialog = new KProgressDialog( this, "progress_dialog", QString::null, text, false );
-
-    progressDialog->setAllowCancel( true );
-    progressDialog->showCancelButton( true );
-    progressDialog->setPlainCaption( i18n( "Please Wait" ) );
-
-    progressDialog->progressBar()->setTotalSteps( 0 );
-    progressDialog->progressBar()->setPercentageVisible( false );
-
-    progressDialog->setMinimumDuration( 500 );
-    progressDialog->show();
-
-    timer = new QTimer( this );
-    connect( timer, SIGNAL( timeout() ), this, SLOT( slotProg() ) );
-
-    timer->start( 200, FALSE );
-}
-
-void Freshklam::slotProg()
-{
-
-    if (progressDialog)
-        progressDialog->progressBar()->setProgress(progressDialog->progressBar()->progress() + 4 );
-}
-
-void Freshklam::clamavInstallationExited(KProcess* arkollonproc)
-{
-
-    arkollonproc = 0;
-    delete arkollonproc;
-    upgradeinprogress = false;
-    getCurrentVersionOfClamAV( );
-
-}
-
-void Freshklam::klamavInstallationExited(KProcess* arkollonproc)
-{
-
-    arkollonproc = 0;
-    delete arkollonproc;
-    upgradeinprogress = false;
-
-    KMessageBox::information (this,"If the installation of KlamAV completed successfully you should restart KlamAV for the new version to take effect.");
-
+    updater->checkForNewKlamAVDirectly();
 }
 
 void
@@ -1157,7 +946,7 @@ void
 Freshklam::connectToHost() //SLOT
 {
 
-        //kdDebug() << m_url.host() << endl;
+        ////kdDebug() << m_url.host() << endl;
 
         m_resolver.setNodeName( m_url.host() );
         m_resolver.setFamily( KResolver::InetFamily );
@@ -1171,18 +960,20 @@ Freshklam::resolved( KResolverResults result) // SLOT
 {
 
     if ((!( result.error() != KResolver::NoError || result.isEmpty() )) 
-       && klamav_box->isChecked())
-        checkForNewKlamAV();
-    else
+       && klamav_box->isChecked()){
+    	updater->checkForNewKlamAV();
+    }else
         kdDebug() << "network error or not set to check for new klamav" << endl;
 }
 
+
 void
 Freshklam::getCurrentVersionOfClamAV( )
 {
 
-        //kdDebug() << "version clamav" << endl;
+        ////kdDebug() << "version clamav" << endl;
 	QString suCommand=QString("clamscan -V");
+
 	versionproc = new KProcIO();
 	versionproc->setUseShell(TRUE);
 	versionproc->setUsePty (KProcIO::Stdout,TRUE);
@@ -1191,8 +982,17 @@ Freshklam::getCurrentVersionOfClamAV( )
 	
 	connect( versionproc, SIGNAL(readReady(KProcIO *)),
 		SLOT(readVersionLine(KProcIO *)) );
-	versionproc->start(KProcIO::NotifyOnExit);
+	connect( versionproc, SIGNAL(processExited(KProcess *)),
+			SLOT(versionExited()) );
 
+	versionproc->start(KProcIO::NotifyOnExit);
+    versionproc->closeWhenDone();
+}
+
+void Freshklam::versionExited()
+{
+    kdDebug() << "deleting versionproc" << endl;
+    delete versionproc;
 }
 
 void Freshklam::readVersionLine(KProcIO *)
@@ -1205,10 +1005,10 @@ void Freshklam::readVersionLine(KProcIO *)
 			lineout = lineout.stripWhiteSpace();
 			int StartPoint = (lineout.find("ClamAV") + 6);
 			int EndPoint = lineout.find("/");
-			currentClamAVVersion = lineout.mid(StartPoint,(EndPoint - StartPoint));
+			QString currentClamAVVersion = lineout.mid(StartPoint,(EndPoint - StartPoint));
                         currentClamAVVersion = currentClamAVVersion.stripWhiteSpace();
-                        //kdDebug() << currentClamAVVersion << endl;
-                        
+			KlamavConfig::setClamAVVersion(currentClamAVVersion);
+                        ////kdDebug() << currentClamAVVersion << endl;
 		}
    	}
 	versionproc->ackRead();
@@ -1217,179 +1017,12 @@ void Freshklam::readVersionLine(KProcIO *)
 
 }
 
-
-void Freshklam::getLatestVersionFromSF(KURL url)
+void Freshklam::toggleUpgradeButtons(bool state)
 {
 
-    //kdDebug() << "getting latest version" << endl;
-    //kdDebug() << url << endl;
-    klamav_options->setDisabled(true);
-    clamav_options->setDisabled(true);
+    klamav_options->setEnabled(state);
+    clamav_options->setEnabled(state);
 
-    filelist = new KHTMLPart();
-    connect( filelist, SIGNAL( completed() ), this,
-		SLOT( parseSFPage() ) );
-
-    filelist->openURL(url);
-    if (progressDialog)
-        connect( progressDialog, SIGNAL( cancelClicked() ), this,
-		SLOT( updateCanceled() ) );
-
-}
-
-void Freshklam::getLatestVersionFromSFHack(KURL url)
-{
-
-    //kdDebug() << "getting latest version" << endl;
-    //kdDebug() << url << endl;
-    klamav_options->setDisabled(true);
-    clamav_options->setDisabled(true);
-
-    filelist = new KHTMLPart();
-    connect( filelist, SIGNAL( completed() ), this,
-		SLOT( parseSFPageHack() ) );
-
-    filelist->openURL(url);
-
-}
-
-
-
-void Freshklam::updateCanceled()
-{
-
-    //kdDebug() << "cancelled" << endl;
-    filelist->closeURL();
-    klamav_options->setEnabled(true);
-    clamav_options->setEnabled(true);
-
-}
-
-void Freshklam::parseSFPage()
-{
-
-
-    //kdDebug() << "parsing sf page" << endl;
-
-
-    const DOM::HTMLCollection links = filelist->htmlDocument().links();
-    //kdDebug() << links.length() << endl;
-
-    if (links.length() == 0){
-            KMessageBox::information (this,"Could not contact update server!");
-            updateCanceled();
-            delete progressDialog;
-            progressDialog = 0;
-            return;
-    }
-    
-    disconnect( filelist, SIGNAL( completed() ), this,
-	SLOT( parseSFPage() ) );
-
-    for (unsigned int j=0; j != links.length(); j++ ){
-        const DOM::Node linkNode = links.item( j );
-        getVersionFromLink( linkNode );
-    }
-
-    delete progressDialog;
-    progressDialog = 0;
-    
-    //kdDebug() << highestsofarfilename << endl;
-    if (highestsofarfilename.contains("klamav"))
-        completedSearchForUpdates("KlamAV", "tar.bz2");
-    else if (highestsofarfilename.contains("clamav"))
-        completedSearchForUpdates("ClamAV", "tar.gz");
-
-}
-
-void Freshklam::parseSFPageHack()
-{
-
-
-    //kdDebug() << "parsing sf page" << endl;
-
-
-    const DOM::HTMLCollection links = filelist->htmlDocument().links();
-    //kdDebug() << links.length() << endl;
-
-    if (links.length() == 0){
-            return;
-    }
-    
-    disconnect( filelist, SIGNAL( completed() ), this,
-	SLOT( parseSFPage() ) );
-
-    for (unsigned int j=0; j != links.length(); j++ ){
-        const DOM::Node linkNode = links.item( j );
-        getVersionFromLink( linkNode );
-    }
-
-    //delete progressDialog;
-    //progressDialog = 0;
-    
-    //kdDebug() << highestsofarfilename << endl;
-    if (highestsofarfilename.contains("klamav"))
-        completedSearchForUpdates("KlamAV", "tar.bz2");
-    else if (highestsofarfilename.contains("clamav"))
-        completedSearchForUpdates("ClamAV", "tar.gz");
-
-}
-
-
-void Freshklam::getVersionFromLink( const DOM::Node &n )
-{
-        double numericversion;
-        QString tmpversion;
-
-        if ( n.isNull() || n.nodeType() != DOM::Node::ELEMENT_NODE )
-            return;
-        
-        DOM::Element elem = static_cast<DOM::Element>( n );
-        
-        KURL href ( elem.getAttribute( "href" ).string() );
-        
-        //kdDebug() << href.filename() << endl;
-
-        QString name = href.filename();
-        QString version = name.replace(".tar.bz2","").replace(".tar.gz","");
-        version = version.replace("clamav-","").replace("klamav-","");
-
-        tmpversion = version;
-
-        if ((tmpversion.mid(tmpversion.length() - 2,1) == ".") && (tmpversion.length() > 3))
-            numericversion = tmpversion.replace(tmpversion.length() - 2,1,"").toDouble();
-        else
-            numericversion = tmpversion.toDouble();
-
-        //kdDebug() << version << endl;
-        //kdDebug() << numericversion << endl;
-        if (numericversion > highestsofarnumeric){
-            highestsofarnumeric = numericversion;
-            highestsofarraw = version;
-            highestsofarfilename = href.filename();
-        }
-
-
-}
-
-QString Freshklam::getMirror()
-{
-
-    int r=1+(int) (16.0*rand()/(RAND_MAX+1.0));
-
-    //kdDebug() << r << endl;
-    return mirrors[r];
-}
-
-void Freshklam::enableAutoUpdates()
-{
-
-        config = KGlobal::config();
-        config->writeEntry("AutoUpdate","Yes");
-        config->sync();
-        daemon_box->setChecked(true);
-        check_combo->setEnabled(true);
-	slotSearch();
 
 }
 
