@@ -5,7 +5,8 @@
 #include "klamd.h"
 #include "klamav.h"
 #include "freshklam.h"
-#include "klamdoptions.h"
+#include "klamavconfig.h"
+#include "collectiondb.h"
 
 
 
@@ -25,6 +26,8 @@
 #include <kmessagebox.h>
 #include <ktempfile.h>
 #include <ksystemtray.h>
+#include <qtoolbutton.h>
+
 
 
 const char *check_desc1[] = {
@@ -78,6 +81,8 @@ Klamd::Klamd(QWidget *_parent, const char *name)
 	m_fileTreeView->addColumn( i18n("Include") );
 	treeBranch = m_fileTreeView->addBranch( root, i18n("Root"), SmallIcon("folder_red") );
 	m_fileTreeView->setDirOnlyMode( treeBranch, true );
+        treeBranch->setShowingDotFiles( true );
+
 
 	treeBranch->setOpen( true );
 
@@ -127,7 +132,7 @@ Klamd::Klamd(QWidget *_parent, const char *name)
 	m_fileTreeView2->addColumn( i18n("Exclude") );
 	treeBranch2 = m_fileTreeView2->addBranch( root2, i18n("Root"), SmallIcon("folder_red") );
 	m_fileTreeView2->setDirOnlyMode( treeBranch2, true );
-
+        treeBranch2->setShowingDotFiles( true );
 	treeBranch2->setOpen( true );
 
 	btnup2 = new KArrowButton(hlp2, LeftArrow);
@@ -219,8 +224,13 @@ Klamd::Klamd(QWidget *_parent, const char *name)
 	dir_layout3->addSpacing(20);
 
 
+ 	QToolButton* adv_options = new QToolButton( hlp3,"play" );
+ 	adv_options->setIconSet( SmallIconSet( "configure" ) );
+	adv_options->setTextLabel("Options");
+	adv_options->setTextPosition(QToolButton::Right);
+	adv_options->setUsesTextLabel(true);
 	
-	adv_options = new QPushButton ("Advanced", hlp3);
+//	adv_options = new QPushButton ("Advanced", hlp3);
 	dir_layout3->addWidget(adv_options);
 	//adv_options->setFixedSize(adv_options->sizeHint());
 
@@ -292,6 +302,7 @@ void Klamd::processOutput()
 			//kdDebug() << "tmpFName " << tmpFName << endl;
 			//kdDebug() << "tmpVirusName " << tmpVirusName << endl;
 			tmpVirusName.replace("FOUND","");
+            CollectionDB::instance()->insertEvent("Virus Found",tmpVirusName,tmpFName);
 			if (recursive_box->isChecked())
 				Quarantine(tmpFName.stripWhiteSpace(),tmpVirusName.stripWhiteSpace());
 		}
@@ -343,6 +354,8 @@ void Klamd::finish()
 	
 	buf += '\n';
 	processOutput();
+    childproc->closeAll();
+    childproc->kill(9);
 	delete childproc;
 	childproc = 0;
 	klamdAlive = FALSE;
@@ -358,6 +371,8 @@ void Klamd::slotCancel()
 {
     finish();
 
+    CollectionDB::instance()->insertEvent("Auto-Scan","Scanning Cancelled","");
+
 }
 
 
@@ -368,7 +383,7 @@ void Klamd::childExited()
 
     kmain->contextDisable();
     
-    KMessageBox::information (this,"The auto-scan process died unexpectedly!");
+    KMessageBox::information (this,i18n( "The auto-scan process died unexpectedly!") );
 
     //if (status != 0)
 	      //matches_label->setText("");
@@ -518,14 +533,15 @@ void Klamd::writeConf()
 
 	QTextStream &ts = *(tf.textStream());
 
-	ts << "LocalSocket /tmp/klamd " << "\n";
-	ts << "MaxDirectoryRecursion 15" << "\n";
+	//ts << "LocalSocket /tmp/klamd " << "\n";
+    ts << "TCPSocket 9888 " << "\n";
+/*	ts << "MaxDirectoryRecursion 15" << "\n";*/
 	ts << "Foreground" << "\n";
 	ts << "LogFile /dev/stdout" << "\n";
 	ts << "ScanArchive" << "\n";
 	//ts << "ClamukoMaxFileSize " << check_combo->currentText() << "M\n";
-	ts << "ArchiveMaxRecursion 5" << "\n";
-	ts << "ArchiveMaxFiles 1000" << "\n";
+/*	ts << "ArchiveMaxRecursion 5" << "\n";
+	ts << "ArchiveMaxFiles 1000" << "\n";*/
 	ts << "FixStaleSocket" << "\n";
 	ts << "SelfCheck 1800" << "\n";
 	ts << QString("DatabaseDirectory %1").arg(db) << "\n";
@@ -544,25 +560,25 @@ void Klamd::writeConf()
 	config->setGroup("Klamd");
 
 
-	if (config->readEntry("Executed") == "Yes")
+	if (KlamavConfig::executed())
 		ts << "ClamukoScanOnExec" << "\n";
 
-	if (config->readEntry("Created") == "Yes"){
+	if (KlamavConfig::created()){
 		ts << "ClamukoScanOnCloseModified" << "\n";
 		clamdcommand = "klamd";
 	}else{
 		clamdcommand = "clamd";
 		
-		if (config->readEntry("Opened") == "Yes")
+		if (KlamavConfig::opened())
 			ts << "ClamukoScanOnOpen" << "\n";
 	
-		if (config->readEntry("Closed") == "Yes")
+		if (KlamavConfig::closed())
 			ts << "ClamukoScanOnClose" << "\n";
 	}
-	if (config->readEntry("ScanArchives") == "Yes"){
+/*	if (config->readEntry("ScanArchives") == "Yes"){
 		ts << "ClamukoScanArchive" << "\n";
 		ts << "ArchiveMaxFileSize " << config->readEntry("MaxSize") << "M\n";
-	}
+	}*/
 //     if (check_combo2->currentItem() == 0)
 // 	ts << "ClamukoScanOnOpen" << "\n";
 //     else
@@ -644,7 +660,7 @@ void  Klamd::Quarantine(QString fname, QString virusname){
 				if (lastQuarItems.contains(object))
 					lastQuarItems.remove(object);
 				lastQuarItems.prepend(object);
-				
+				CollectionDB::instance()->insertEvent("Quarantine",virusname,fname);
 			}	
 		}else{
 			//kdDebug() << "rename worked" << endl;
@@ -657,7 +673,7 @@ void  Klamd::Quarantine(QString fname, QString virusname){
 			if (lastQuarItems.contains(object))
 				lastQuarItems.remove(object);
 			lastQuarItems.prepend(object);
-			
+			CollectionDB::instance()->insertEvent("Quarantine",virusname,fname);
 		}
 	}
 	
@@ -706,7 +722,7 @@ int  Klamd::runDazuko(bool caller){
 	bool succ = lsmodproc->start(KProcIO::NotifyOnExit,TRUE);
 
 	if (!(succ))
-		KMessageBox::information (this,"There was a problem detecting the loaded status of dazuko.");
+		KMessageBox::information (this,i18n( "There was a problem detecting the loaded status of dazuko.") );
 	return 1;
 }
 
@@ -719,7 +735,7 @@ void Klamd::lsmodOutput()
 		i18n( "Load Module" ),
 		i18n( "Delete2" ));
 		switch (result) {
-			case 2 : KMessageBox::information (this,"Loading of Module Cancelled.");  break;
+			case 2 : KMessageBox::information (this,i18n( "Loading of Module Cancelled.") );  break;
 			case 5 : loadDazuko();  break;
 		}
 
@@ -736,13 +752,16 @@ void Klamd::loadKlamd()
 
 	klamdAlive = TRUE;
 	
-	QString suCommand=QString(clamdcommand+" -c '%1'").arg(tempFileName);
+	//QString suCommand=QString("kdesu -t -c '" +clamdcommand+" -c '%1'").arg(tempFileName)+"'";
+    QString suCommand=QString(clamdcommand+" -c '%1'").arg(tempFileName);
 	childproc = new KProcIO();
 	childproc->setUseShell(TRUE);
 	childproc->setUsePty (KProcIO::Stdout,TRUE);
 	QString curpath = (QString) getenv("PATH");
 	childproc->setEnvironment("PATH",curpath + ":/usr/local/sbin:/usr/sbin:/sbin:/usr/local/bin:/usr/bin:/bin");
 
+	kdDebug() << suCommand << endl;
+
 	*childproc<<suCommand;
 	
 	connect( childproc, SIGNAL(readReady(KProcIO *)),
@@ -766,6 +785,8 @@ void Klamd::loadKlamd()
 	config->sync();
 	disableInputs();
 
+    CollectionDB::instance()->insertEvent("Auto-Scan","Scanning Started","");
+
 }
 void Klamd::loadDazuko()
 {
@@ -790,7 +811,7 @@ void Klamd::loadDazuko()
 	insmodproc->setEnvironment("PATH",curpath + ":/usr/local/sbin:/usr/sbin:/sbin:/usr/local/bin:/usr/bin:/bin");
 
 	insmodproc->setUseShell(TRUE);
-	*insmodproc<<"kdesu"<<"-c"<<insmodCommand;
+	*insmodproc<<"kdesu -i klamav"<<"-c"<<insmodCommand;
 	
 	connect( insmodproc, SIGNAL(processExited(KProcess *)),
 		SLOT(moduleLoaded()) );
@@ -807,7 +828,7 @@ void Klamd::moduleLoaded()
 void Klamd::lsmodCheck()
 {
 	if (!(dazukoLoaded)){
-		KMessageBox::information (this,"Dazuko was not loaded successfully. Please check your installation.");
+		KMessageBox::information (this,i18n( "Dazuko was not loaded successfully. Please check your installation." ));
 	}else{
 		int result;
 		result = KMessageBox::warningContinueCancel(this, i18n( "Module has been loaded. Will now continue to start up real-time scanning."),
@@ -889,7 +910,7 @@ QString  Klamd::getKlamdConfFile(){
 
 void  Klamd::slotAdvOptions(){
 
-	config = KGlobal::config();
+/*	config = KGlobal::config();
 	config->setGroup("Klamd");
 	QString RunKlamd = config->readEntry("Enabled");
 
@@ -900,9 +921,9 @@ void  Klamd::slotAdvOptions(){
 	
 	dialog->show();
 	dialog->raise();
-	dialog->setActiveWindow();
-	
+	dialog->setActiveWindow();*/
 	
+	kmain->slotConfigKlamav( "Auto-Scan" );	
 
 }
 
