@@ -136,11 +136,13 @@ int clamdscan(struct optstruct *opt)
 
                 tmpnm = (char*) mcalloc(strlen(mdir) + 1 + 16 + 1 + 7, sizeof(char));
                 if(tmpnm == NULL) {
-                    return NULL;
+                    exit(2);
                 }
 
+		//snprintf(fullname, sizeof(fullname), "%s/pdfXXXXXX", dir);
+
                 sprintf(tmpnm, "%s/", mdir);
-                sprintf(name,"klammailXXXXXX",19);
+                snprintf(name, sizeof(name), "klammailXXXXXX");
                 strncat(tmpnm, name, 19);
                 mkstemp(tmpnm); 
 
@@ -207,15 +209,15 @@ int clamdscan(struct optstruct *opt)
                                         }
                         }else{
                                 if((ret = cl_loaddbdir(cl_retdbdir(), &root, &no))) {
-                                printf("cl_loaddbdir: %s\n", cl_perror(ret));
+                                printf("cl_loaddbdir: %s\n", cl_strerror(ret));
                                 close(fd);
                                 exit(2);
                                 }
                         }	
                         /* build the final trie */
-                        if((ret = cl_buildtrie(root))) {
+                        if((ret = cl_build(root))) {
         //		printf("Database initialization error: %s\n", cl_strerror(ret));;
-                                cl_freetrie(root); /* free the partial trie */
+                                cl_free(root); /* free the partial trie */
                                 close(fd);
                                 exit(2);
                         }
@@ -244,7 +246,7 @@ int clamdscan(struct optstruct *opt)
                 spoolstdin(fd, ret, &virname, &bndrystore, opt);
 
                 if((ret == 2))
-                        cl_freetrie(root);
+                        cl_free(root);
                         
                 unlink(tmpnm);
 
@@ -477,7 +479,7 @@ int spoolstdin(int fd, int ret, char **virname, const char **bndrystore, struct
                 fclose(tmp);
         } else
                 if(!printinfected)
-                    mprintf("stdin: %s\n", cl_perror(ret));
+                    mprintf("stdin: %s\n", cl_strerror(ret));
         
         return ret;
 }
@@ -531,10 +533,11 @@ void startclamd(struct optstruct *opt)
         char conffile[31];
         struct stat sb;
         FILE *tmp;
-        char *fullpath, cwd[200];
+        char *fullpath; 
+        char cwd[200];
         char *scancmd;
                 
-        sprintf(tmpnm,"klammailXXXXXX",19);
+        snprintf(tmpnm, sizeof(tmpnm), "klammailXXXXXX");
         mkstemp(tmpnm); 
         
         fd = open(tmpnm,O_RDWR|O_CREAT, S_IRWXU);
@@ -548,7 +551,7 @@ void startclamd(struct optstruct *opt)
         fprintf(tmp,"LocalSocket /tmp/KlamMailSock\n");
         fprintf(tmp,"MaxDirectoryRecursion 15\n");
         fprintf(tmp,"SelfCheck 900\n");
-        fprintf(tmp,"ScanArchive\n");
+        //fprintf(tmp,"ScanArchive\n");
         if(optc(opt, 'd')) {
                 stat(getargc(opt, 'd'), &sb);
                 switch(sb.st_mode & S_IFMT) {
@@ -565,14 +568,18 @@ void startclamd(struct optstruct *opt)
         }else{
                 fprintf(tmp,"DatabaseDirectory /usr/local/share/clamav\n");
         }
-        fprintf(tmp,"ScanMail\n");
-        fprintf(tmp,"FixStaleSocket\n");
+        //fprintf(tmp,"ScanMail\n");
+        if ((strstr(cl_retver(), "0.8")) || (strstr(cl_retver(), "0.7")))
+            fprintf(tmp,"FixStaleSocket\n");
+        else
+            fprintf(tmp,"FixStaleSocket TRUE\n");
+
         fflush(tmp);
         
         fclose(tmp);
         close(fd);
 
-        fullpath = mcalloc(200 + strlen(tmpnm) + 10, sizeof(char));
+        fullpath = (char*) mcalloc(200 + strlen(tmpnm) + 10, sizeof(char));
 
         if(!getcwd(cwd, 200)) {
                 mprintf("@Can't get absolute pathname of current working directory.\n");
