@@ -43,7 +43,7 @@ Kuarantine::Kuarantine(QWidget *parent, const char *name)
 		for (QStringList::Iterator it = lastQuarLocations.begin(); it == lastQuarLocations.begin(); it++ )
 		quarloc = *it;
 		if (!(KIO::NetAccess::exists(quarloc,TRUE,NULL))){
-			KMessageBox::information (this,QString("Your current quarantine location ('%1') no longer exists. I'm going to attempt to create a new one.").arg(quarloc));
+			KMessageBox::information (this,i18n( "Your current quarantine location ('%1') no longer exists. I'm going to attempt to create a new one.").arg(quarloc));
 			createQuarDir();
 		}
 	}
@@ -136,9 +136,9 @@ Kuarantine::Kuarantine(QWidget *parent, const char *name)
 	//currentbox->setMinimumSize(rb_fm.width("0")*55,
 	//			rb_fm.lineSpacing()*15);
 	//kdDebug() << ((currentbox->width())/3) << endl;
-	currentbox->addColumn( "Name of File",0);
-        currentbox->addColumn( "Name of Virus Found",0);
-	currentbox->addColumn( "Date Quarantined",0);
+	currentbox->addColumn( i18n( "Name of File" ),0);
+        currentbox->addColumn( i18n( "Name of Virus Found" ),0);
+	currentbox->addColumn( i18n( "Date Quarantined" ),0);
 	currentbox->setResizeMode(QListView::AllColumns);
 	currentbox->setSelectionMode( QListView::Extended );
 	currentbox->setAllColumnsShowFocus(true);
@@ -204,9 +204,9 @@ Kuarantine::Kuarantine(QWidget *parent, const char *name)
 	QFontMetrics rb_fm2(historybox->fontMetrics());
 	//historybox->setMinimumSize(rb_fm2.width("0")*55,
 	//			rb_fm2.lineSpacing()*15);
-	historybox->addColumn( "Name of File",(historybox->width()));
-        historybox->addColumn( "Name of Virus Found",(historybox->width()));
-	historybox->addColumn( "Date Quarantined",(historybox->width()));
+	historybox->addColumn( i18n( "Name of File" ),(historybox->width()));
+        historybox->addColumn( i18n( "Name of Virus Found" ),(historybox->width()));
+	historybox->addColumn( i18n( "Date Quarantined" ),(historybox->width()));
 	historybox->setResizeMode(QListView::AllColumns);
 	historybox->setSelectionMode( QListView::Extended );
 	historybox->setAllColumnsShowFocus(true);
@@ -255,7 +255,7 @@ void Kuarantine::refresh()
 	lastQuarItems = config->readListEntry(QString("Items %1").arg(quarloc));
 	
 	if (!(KIO::NetAccess::exists(quarloc,TRUE,NULL))){
-		KMessageBox::information (this,QString("Your current quarantine location ('%1') no longer exists. I'm going to attempt to create a new one.").arg(quarloc));
+		KMessageBox::information (this,i18n("Your current quarantine location ('%1') no longer exists. I'm going to attempt to create a new one.").arg(quarloc));
 		createQuarDir();
 	}else{
 
@@ -447,7 +447,7 @@ void Kuarantine::slotCancel()
 				//currentbox->takeItem(( it.current() ));
 				list.prepend( it.current() );
 			}else{
-				KMessageBox::information (this,"There was a problem deleting the file. Is there a problem with the permissions on the quarantine folder? ");
+				KMessageBox::information (this,i18n( "There was a problem deleting the file. Is there a problem with the permissions on the quarantine folder? " ));
 			}
 		//}
 	        ++it;
@@ -559,7 +559,7 @@ void  Kuarantine::createQuarDir(){
 		
 	}
 	
-	KMessageBox::information (this,QString(ok ? "Your default quarantine location has been set up as '%1'. You can change this to something else if you want to." : "I cannot create the directory '%1' for you. Something is wrong with your HOME or klamav directory. You have to adjust your quarantine directory by your self.").arg(path));
+	KMessageBox::information (this,QString(ok ? i18n( "Your default quarantine location has been set up as '%1'. You can change this to something else if you want to." ) : i18n( "I cannot create the directory '%1' for you. Something is wrong with your HOME or klamav directory. You have to adjust your quarantine directory by your self." )).arg(path));
 	
 }
 
@@ -585,7 +585,7 @@ QString Kuarantine::getVirusName(QString entry){
 	
 	//kdDebug() << itemName << endl;
 	
-	return itemName;	
+	return itemName.stripWhiteSpace();	
 	
 }
 
@@ -608,6 +608,7 @@ void Kuarantine::slotRMB( QListViewItem* Item, const QPoint & point, int )
 	QPixmap gicon;
 	QPixmap vicon;
 	QPixmap ticon;
+        QPixmap vlicon;
 
         QString iconPath = locate("cache", KMimeType::favIconForURL("http://viruspool.vanderkooij.org")+".png");
         if ( iconPath.isEmpty() )
@@ -627,19 +628,27 @@ void Kuarantine::slotRMB( QListViewItem* Item, const QPoint & point, int )
         else
           ticon = QPixmap( iconPath );
 
+        iconPath = locate("cache", KMimeType::favIconForURL("http://www.viruslist.com")+".png");
+        if ( iconPath.isEmpty() )
+          vlicon = SmallIcon("find");
+        else
+          vlicon = QPixmap( iconPath );
+
 
 	if (Item->listView() == currentbox){
 		qmenu->clear();
-		qmenu->insertItem( vicon,QString("Search for %1 with VirusPool").arg(Item->text(1)), this, SLOT(slotVirusPoolCurrent()) );
-		qmenu->insertItem( ticon,QString("Search for %1 with Trend Micro").arg(Item->text(1)), this, SLOT(slotTrendMicroCurrent()) );
-		qmenu->insertItem( gicon,QString("Search for %1 with Google").arg(Item->text(1)), this, SLOT(slotGoogleCurrent()) );
+		qmenu->insertItem( vlicon,i18n("Search for %1 with VirusList").arg(Item->text(1)), this, SLOT(slotVirusListCurrent()) );
+		qmenu->insertItem( vicon,i18n("Search for %1 with VirusPool").arg(Item->text(1)), this, SLOT(slotVirusPoolCurrent()) );
+		qmenu->insertItem( ticon,i18n("Search for %1 with Trend Micro").arg(Item->text(1)), this, SLOT(slotTrendMicroCurrent()) );
+		qmenu->insertItem( gicon,i18n("Search for %1 with Google").arg(Item->text(1)), this, SLOT(slotGoogleCurrent()) );
 	
 		qmenu->popup( point );
 	}else if (Item->listView() == historybox){
 		hmenu->clear();
-		hmenu->insertItem( vicon,QString("Search for %1 with VirusPool").arg(Item->text(1)), this, SLOT(slotVirusPoolHistory()) );
-		hmenu->insertItem( ticon,QString("Search for %1 with Trend Micro").arg(Item->text(1)), this, SLOT(slotTrendMicroHistory()) );
-		hmenu->insertItem( gicon,QString("Search for %1 with Google").arg(Item->text(1)), this, SLOT(slotGoogleHistory()) );
+		hmenu->insertItem( vicon,i18n("Search for %1 with VirusPool").arg(Item->text(1)), this, SLOT(slotVirusPoolHistory()) );
+		hmenu->insertItem( vicon,i18n("Search for %1 with VirusList").arg(Item->text(1)), this, SLOT(slotVirusListHistory()) );
+		hmenu->insertItem( ticon,i18n("Search for %1 with Trend Micro").arg(Item->text(1)), this, SLOT(slotTrendMicroHistory()) );
+		hmenu->insertItem( gicon,i18n("Search for %1 with Google").arg(Item->text(1)), this, SLOT(slotGoogleHistory()) );
 	
 		hmenu->popup( point );
 	}
@@ -652,6 +661,12 @@ void Kuarantine::slotVirusPoolCurrent()
 	kmain->klamdb->slotExternal(name,"VirusPool");
 }
 
+void Kuarantine::slotVirusListCurrent()
+{
+	QString name = currentbox->currentItem()->text(1);
+	kmain->klamdb->slotExternal(name,"VirusList");
+}
+
 void Kuarantine::slotGoogleCurrent()
 {
 	QString name = currentbox->currentItem()->text(1);
@@ -671,6 +686,12 @@ void Kuarantine::slotVirusPoolHistory()
 	kmain->klamdb->slotExternal(name,"VirusPool");
 }
 
+void Kuarantine::slotVirusListHistory()
+{
+	QString name = historybox->currentItem()->text(1);
+	kmain->klamdb->slotExternal(name,"VirusList");
+}
+
 void Kuarantine::slotGoogleHistory()
 {
 	QString name = historybox->currentItem()->text(1);
